## Description

Please include a summary of the changes and the related issue.  
Fixes # (issue)

## How Has This Been Tested?

- [ ] Linted with `ruff check .`  
- [ ] Ran `pytest`  

## Types of changes

- [ ] Bug fix (`bug`)
- [ ] New feature (`enhancement`)
- [ ] New feature (`documentation`)
- [ ] Other (please describe):

## Checklist

- [ ] Performed a self-review  
- [ ] Add numpy-type docs
- [ ] Align with current package versions  
- [ ] My changes generate no new warnings  
